using System;
using System.Collections;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.ComponentModel;
using System.Diagnostics;

namespace Mayo.Controls.AuthorBio
{
	/// <summary>
	/// Summary description for AuthorBio.
	/// </summary>
	[DefaultProperty("Text"),
                DefaultEvent("Click"),
		ToolboxData("<{0}:AuthorBio runat=server></{0}:AuthorBio>")]
	public class AuthorBio : System.Web.UI.WebControls.WebControl, INamingContainer
	{
                private string authorName;

                private Hashtable authorBios = new Hashtable();

                private Label      lblAuthorName = new Label();
                private Label      lblAuthorBio  = new Label();
                private LinkButton lkbAuthorSite = new LinkButton();

        	[Bindable(true),
			Category("Appearance"),
			DefaultValue("")]
		public string AuthorName
		{
			get
			{
				return authorName;
			}
			set
			{
				authorName = value;
                                EnsureChildControls();
			}
		}

                // returns bio for current author
                protected string Bio
                {
                        get
                        {
                                EnsureChildControls();

                                LoadAuthorData();

                                AuthorBioInfo info = (AuthorBioInfo)authorBios[AuthorName];

                                string bio = "No Bio Specified";

                                if (info != null)
                                        bio = info.AuthorBio;

                                return bio;
                        }
                }

                // returns site of current author
                protected string AuthorSite
                {
                        get
                        {
                                EnsureChildControls();

                                LoadAuthorData();

                                AuthorBioInfo info = (AuthorBioInfo)authorBios[AuthorName];

                                string site = "No Site Specified";
                                
                                if (info != null)
                                        site = info.AuthorSite;

                                return site;
                        }
                }

                // loads the authors and their bios
                protected void LoadAuthorData()
                {
                        EnsureChildControls();

                        AuthorBioInfo info = new AuthorBioInfo();

                        info.AuthorName = "Jane Doe";
                        info.AuthorSite = "http://www.InformIT.com";
                        info.AuthorBio = @"
Jane Doe is a freelance author and software<br>
consultant with 25 years of experience. You<br>
may contact her at: jdoe@somedomain.com";

                        authorBios[info.AuthorName] = info;

                        info = new AuthorBioInfo();

                        info.AuthorName = "John Smith";
                        info.AuthorSite = "http://www.InformIT.com";
                        info.AuthorBio = @"
John Smith has been developing .NET software<br>
for over 2 years.  He has a Bachelors Degree<br>
in Computer Science from XYZ University.";

                        authorBios[info.AuthorName] = info;
                }

                // adds constituent controls
                protected override void CreateChildControls()
                {
                        // title
                        Controls.Add(new LiteralControl(
                                "<p><i>About the Author</i></p><p><b>"));

                        // author name
                        lblAuthorName.Text = AuthorName;
                        Controls.Add(lblAuthorName);

                        // line break
                        Controls.Add(new LiteralControl("</b></p><p>"));

                        // author bio
                        lblAuthorBio.Text = Bio;
                        Controls.Add(lblAuthorBio);

                        // line break
                        Controls.Add(new LiteralControl("</p><p>"));

                        // author site
                        lkbAuthorSite.Text = "Visit " + AuthorName + "'s Web Site";
                        lkbAuthorSite.Click += new EventHandler(AuthorSite_Click);
                        Controls.Add(lkbAuthorSite);

                        // line break
                        Controls.Add(new LiteralControl("</p>"));
                }

                // notify user that site link was clicked
                public event EventHandler Click;

                // callback on Author's Site link click.
                protected void AuthorSite_Click(object sender, EventArgs e)
                {
                        EnsureChildControls();

                        // raise event
                        if (Click != null)
                        {
                                Click(this, EventArgs.Empty);
                        }

                        // move to author's site
                        Page.Response.Redirect(AuthorSite);
                }


/* Initial Implementation.
// Shown for simplified demonstration.
// Replaced by more dynamic implementation.
                protected override void CreateChildControls()
                {
                        EnsureChildControls();

                       // title
                        Controls.Add(new LiteralControl(
                                "<p><i>About the Author</i></p><p><b>"));

                        // author name
                        lblAuthorName.Text = "Jane Doe";
                        Controls.Add(lblAuthorName);

                        // line break
                        Controls.Add(new LiteralControl("</b></p><p>"));

                        // author bio
                        lblAuthorBio.Text = @"
Jane Doe is a freelance author and software<br>
consultant with 25 years of experience. You<br>
may contact her at: jdoe@somedomain.com";
                        Controls.Add(lblAuthorBio);

                        // line break
                        Controls.Add(new LiteralControl("</p><p>"));

                        // author site
                        lkbAuthorSite.Text = "Visit " + "Jane Doe" + "'s Web Site";
                        lkbAuthorSite.Click += new EventHandler(AuthorSite_Click);
                        Controls.Add(lkbAuthorSite);

                        // line break
                        Controls.Add(new LiteralControl("</p>"));
                }
*/

/*
		/// <summary>
		/// Render this control to the output parameter specified.
		/// </summary>
		/// <param name="output"> The HTML writer to write out to </param>
		protected override void Render(HtmlTextWriter output)
		{
			output.Write(Text);
		}
*/
	}
}
